<?php

/**
 * Options for the theme via WordPress Customizer.
 *
 * @author akshitsethi
 * -------------------------------------------------
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

function moscow_customize_register( $wp_customize ) {

	/**
	 * -------------------------------------------------
	 * Sections
	 * -------------------------------------------------
	 */

	// General
	$wp_customize->add_section( 'general', array(
		'title' 		=> esc_html__( 'General', 'moscow' ),
		'capability' 	=> 'edit_theme_options',
		'description' 	=> esc_html__( 'General settings for the theme.', 'moscow' ),
		'priority' 		=> 10
	) );


	// Homepage
	$wp_customize->add_section( 'homepage', array(
		'title' 		=> esc_html__( 'Homepage', 'moscow' ),
		'capability' 	=> 'edit_theme_options',
		'description' 	=> esc_html__( 'Homepage settings for the theme.', 'moscow' ),
		'priority' 		=> 10
	) );


	// Header
	$wp_customize->add_section( 'header', array(
		'title' 		=> esc_html__( 'Header', 'moscow' ),
		'capability' 	=> 'edit_theme_options',
		'description' 	=> esc_html__( 'Header settings for the theme.', 'moscow' ),
		'priority' 		=> 10
	) );


	// Post
	$wp_customize->add_section( 'post', array(
		'title' 		=> esc_html__( 'Post', 'moscow' ),
		'capability' 	=> 'edit_theme_options',
		'description' 	=> esc_html__( 'Post settings for the theme.', 'moscow' ),
		'priority' 		=> 10
	) );


	// Footer
	$wp_customize->add_section( 'footer', array(
		'title' 		=> esc_html__( 'Footer', 'moscow' ),
		'capability' 	=> 'edit_theme_options',
		'description' 	=> esc_html__( 'Footer settings for the theme.', 'moscow' ),
		'priority' 		=> 10
	) );


	// Contact
	$wp_customize->add_section( 'contact', array(
		'title' 		=> esc_html__( 'Contact', 'moscow' ),
		'capability' 	=> 'edit_theme_options',
		'description' 	=> esc_html__( 'Contact settings for the theme.', 'moscow' ),
		'priority' 		=> 10
	) );


	// Social
	$wp_customize->add_section( 'social', array(
		'title' 		=> esc_html__( 'Social', 'moscow' ),
		'capability' 	=> 'edit_theme_options',
		'description' 	=> esc_html__( 'Social links for use in the theme.', 'moscow' ),
		'priority' 		=> 10
	) );


	/**
	 * -------------------------------------------------
	 * Settings
	 * -------------------------------------------------
	 */

	// Layout
	$wp_customize->add_setting( 'layout_style', array(
		'default'    		=> 'normal',
		'sanitize_callback' => 'moscow_sanitize_layout'
	) );


	// Sidebar
	$wp_customize->add_setting( 'sidebar', array(
		'default'    		=> 'right',
		'sanitize_callback' => 'moscow_sanitize_sidebar'
	) );


	// Blog
	$wp_customize->add_setting( 'blog_style', array(
		'default'    		=> 'classic',
		'sanitize_callback' => 'moscow_sanitize_blog'
	) );


	// Pagination
	$wp_customize->add_setting( 'pagination_style', array(
		'default'    		=> 'navigation',
		'sanitize_callback' => 'moscow_sanitize_pagination'
	) );


	// Preloader
	$wp_customize->add_setting( 'preloader', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Links Hover
	$wp_customize->add_setting( 'links_hover', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Featured
	$wp_customize->add_setting( 'featured', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Featured Style
	$wp_customize->add_setting( 'featured_style', array(
		'default'    		=> 'five',
		'sanitize_callback' => 'moscow_sanitize_featured'
	) );


	// Featured Items
	$wp_customize->add_setting( 'featured_items', array(
		'default'    		=> '4',
		'sanitize_callback' => 'moscow_sanitize_number'
	) );


	// Featured Order
	$wp_customize->add_setting( 'featured_items_order', array(
		'default'    		=> 'DESC',
		'sanitize_callback' => 'moscow_sanitize_order'
	) );


	// Color Overlay
	$wp_customize->add_setting( 'featured_color_overlay', array(
		'default'    		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Sticky Header
	$wp_customize->add_setting( 'sticky', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Header Search
	$wp_customize->add_setting( 'header_search', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Breadcrumbs
	$wp_customize->add_setting( 'breadcrumbs', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Post
	$wp_customize->add_setting( 'post_style', array(
		'default'	 		=> 'classic',
		'sanitize_callback' => 'moscow_sanitize_post'
	) );


	// Related Posts
	$wp_customize->add_setting( 'blog_related_posts', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Related Posts Count
	$wp_customize->add_setting( 'blog_related_posts_number', array(
		'default'	 		=> '5',
		'sanitize_callback' => 'moscow_sanitize_number'
	) );


	// Related Posts Title
	$wp_customize->add_setting( 'blog_related_title', array(
		'default'	 		=> esc_html__( 'Related Posts', 'moscow' ),
		'sanitize_callback' => 'sanitize_text_field'
	) );


	// Blog Header
	$wp_customize->add_setting( 'blog_header', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Header Title
	$wp_customize->add_setting( 'blog_header_title', array(
		'default'	 		=> esc_html__( 'Blog', 'moscow' ),
		'sanitize_callback' => 'sanitize_text_field'
	) );


	// Header Description
	$wp_customize->add_setting( 'blog_header_description', array(
		'default'	 		=> esc_html__( 'News trending this week..', 'moscow' ),
		'sanitize_callback' => 'sanitize_text_field'
	) );


	// Blog Tags
	$wp_customize->add_setting( 'blog_tags', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Blog Author
	$wp_customize->add_setting( 'blog_author', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Blog Post Navigation
	$wp_customize->add_setting( 'blog_post_navigation', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Social Icons
	$wp_customize->add_setting( 'footer_social_icons', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Move Top
	$wp_customize->add_setting( 'move_top', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Contact Sidebar
	$wp_customize->add_setting( 'contact_sidebar', array(
		'default'	 		=> false,
		'sanitize_callback' => 'moscow_sanitize_checkbox'
	) );


	// Facebook
	$wp_customize->add_setting( 'social_facebook', array(
		'default'	 		=> '',
		'sanitize_callback' => 'sanitize_text_field'
	) );


	// Twitter
	$wp_customize->add_setting( 'social_twitter', array(
		'default'	 		=> '',
		'sanitize_callback' => 'sanitize_text_field'
	) );


	// Google Plus
	$wp_customize->add_setting( 'social_google_plus', array(
		'default'	 		=> '',
		'sanitize_callback' => 'sanitize_text_field'
	) );


	// LinkedIn
	$wp_customize->add_setting( 'social_linkedin', array(
		'default'	 		=> '',
		'sanitize_callback' => 'sanitize_text_field'
	) );


	// Pinterest
	$wp_customize->add_setting( 'social_pinterest', array(
		'default'	 		=> '',
		'sanitize_callback' => 'sanitize_text_field'
	) );


	// Instagram
	$wp_customize->add_setting( 'social_instagram', array(
		'default'	 		=> '',
		'sanitize_callback' => 'sanitize_text_field'
	) );


	// Youtube
	$wp_customize->add_setting( 'social_youtube', array(
		'default'	 		=> '',
		'sanitize_callback' => 'sanitize_text_field'
	) );


	/**
	 * -------------------------------------------------
	 * Controls
	 * -------------------------------------------------
	 */

	// Layout
	$wp_customize->add_control( 'layout_style',
		array(
			'label' 			=> esc_html__( 'Layout', 'moscow' ),
			'description' 		=> esc_html__( 'Select style for the layout.', 'moscow' ),
			'section' 			=> 'general',
			'type' 				=> 'select',
			'choices' 			=> array(
				'boxed' 		=> esc_html__( 'Boxed', 'moscow' ),
				'normal' 		=> esc_html__( 'Normal', 'moscow' )
			)
		)
	);


	// Sidebar
	$wp_customize->add_control( 'sidebar',
		array(
			'label' 			=> esc_html__( 'Sidebar Position', 'moscow' ),
			'description' 		=> esc_html__( 'Select position for the sidebar. `Disable Sidebar` assigns full width to the content area.', 'moscow' ),
			'section' 			=> 'general',
			'type' 				=> 'select',
			'choices' 			=> array(
				'left' 		=> esc_html__( 'Left', 'moscow' ),
				'right' 	=> esc_html__( 'Right', 'moscow' ),
				'none' 		=> esc_html__( 'Disable Sidebar', 'moscow' )
			)
		)
	);


	// Blog
	$wp_customize->add_control( 'blog_style',
		array(
			'label' 			=> esc_html__( 'Blog Style', 'moscow' ),
			'description' 		=> esc_html__( 'Select style for displaying blog posts. This is for the index, archive, author, and search pages.', 'moscow' ),
			'section' 			=> 'general',
			'type' 				=> 'select',
			'choices' 			=> array(
				'classic' 	=> esc_html__( 'Classic', 'moscow' ),
				'circle' 	=> esc_html__( 'Circle', 'moscow' ),
				'square' 	=> esc_html__( 'Square', 'moscow' ),
				'2-col' 	=> esc_html__( '2 columns', 'moscow' ),
				'3-col' 	=> esc_html__( '3 columns', 'moscow' )
			)
		)
	);


	// Pagination
	$wp_customize->add_control( 'pagination_style',
		array(
			'label' 			=> esc_html__( 'Pagination Style', 'moscow' ),
			'description' 		=> esc_html__( 'Select style for blog pagination. This is for the index, archive, author, and search pages.', 'moscow' ),
			'section' 			=> 'general',
			'type' 				=> 'select',
			'choices' 			=> array(
				'pagination' 	=> esc_html__( 'Pagination', 'moscow' ),
				'navigation' 	=> esc_html__( 'Navigation', 'moscow' )
			)
		)
	);


	// Preloader
	$wp_customize->add_control( 'preloader',
		array(
			'label' 			=> esc_html__( 'Enable Preloader?', 'moscow' ),
			'description' 		=> esc_html__( 'Check this box if you would like to have a nice pre-loading effect before every page request.', 'moscow' ),
			'section' 			=> 'general',
			'type' 				=> 'checkbox'
		)
	);


	// Links Hover
	$wp_customize->add_control( 'links_hover',
		array(
			'label' 			=> esc_html__( 'Enable Hover Style on Links?', 'moscow' ),
			'description' 		=> esc_html__( 'Check this box if you would like to enable a sweet hover effect on links.', 'moscow' ),
			'section' 			=> 'general',
			'type' 				=> 'checkbox'
		)
	);


	// Featured
	$wp_customize->add_control( 'featured',
		array(
			'label' 			=> esc_html__( 'Enable Featured Section?', 'moscow' ),
			'section' 			=> 'homepage',
			'type' 				=> 'checkbox'
		)
	);


	// Featured Style
	$wp_customize->add_control( 'featured_style',
		array(
			'label' 			=> esc_html__( 'Featured Style', 'moscow' ),
			'description' 		=> esc_html__( 'Select style for the featured section.', 'moscow' ),
			'section' 			=> 'homepage',
			'type' 				=> 'select',
			'choices' 			=> array(
				'one' 		=> esc_html__( 'One', 'moscow' ),
				'two' 		=> esc_html__( 'Two', 'moscow' ),
				'three' 	=> esc_html__( 'Three', 'moscow' ),
				'four' 		=> esc_html__( 'Four', 'moscow' ),
				'five' 		=> esc_html__( 'Five', 'moscow' )
			)
		)
	);


	// Featured Items
	$wp_customize->add_control( 'featured_items',
		array(
			'label' 			=> esc_html__( 'Featured Items', 'moscow' ),
			'description' 		=> esc_html__( 'This option affects the `Style 4` of the featured section.', 'moscow' ),
			'section' 			=> 'homepage',
			'type' 				=> 'select',
			'choices' 			=> array(
				'1' 	=> '1',
				'2' 	=> '2',
				'3' 	=> '3',
				'4' 	=> '4',
				'5' 	=> '5',
				'6' 	=> '6',
				'7' 	=> '7',
				'8' 	=> '8',
				'9' 	=> '9',
				'10' 	=> '10'
			)
		)
	);


	// Featured Order
	$wp_customize->add_control( 'featured_items_order',
		array(
			'label' 			=> esc_html__( 'Featured Items Order', 'moscow' ),
			'description' 		=> esc_html__( 'Select order for the featured items.', 'moscow' ),
			'section' 			=> 'homepage',
			'type' 				=> 'select',
			'choices' 			=> array(
				'ASC' 		=> esc_html__( 'Ascending', 'moscow' ),
				'DESC' 		=> esc_html__( 'Descending', 'moscow' ),
				'rand' 	=> esc_html__( 'Random', 'moscow' )
			)
		)
	);


	// Color Overlay
	$wp_customize->add_control( 'featured_color_overlay',
		array(
			'label' 			=> esc_html__( 'Enable Color Overlay?', 'moscow' ),
			'section' 			=> 'homepage',
			'type' 				=> 'checkbox'
		)
	);


	// Sticky Header
	$wp_customize->add_control( 'sticky',
		array(
			'label' 			=> esc_html__( 'Enable Sticky Header?', 'moscow' ),
			'section' 			=> 'header',
			'type' 				=> 'checkbox'
		)
	);


	// Header Search
	$wp_customize->add_control( 'header_search',
		array(
			'label' 			=> esc_html__( 'Add Search Option in the Header?', 'moscow' ),
			'section' 			=> 'header',
			'type' 				=> 'checkbox'
		)
	);


	// Breadcrumbs
	$wp_customize->add_control( 'breadcrumbs',
		array(
			'label' 			=> esc_html__( 'Enable Breadcrumbs?', 'moscow' ),
			'section' 			=> 'post',
			'type' 				=> 'checkbox'
		)
	);


	// Post
	$wp_customize->add_control( 'post_style',
		array(
			'label' 			=> esc_html__( 'Post Style', 'moscow' ),
			'description' 		=> esc_html__( 'Select style for the single post.', 'moscow' ),
			'section' 			=> 'post',
			'type' 				=> 'select',
			'choices' 			=> array(
				'classic' 	=> esc_html__( 'Classic', 'moscow' ),
				'fitted' 	=> esc_html__( 'Fitted', 'moscow' )
			)
		)
	);


	// Related Posts
	$wp_customize->add_control( 'blog_related_posts',
		array(
			'label' 			=> esc_html__( 'Show Related Posts?', 'moscow' ),
			'description' 		=> esc_html__( 'Would you like to show related posts below the post content? If yes, then tick this option.', 'moscow' ),
			'section' 			=> 'post',
			'type' 				=> 'checkbox'
		)
	);


	// Related Posts Count
	$wp_customize->add_control( 'blog_related_posts_number',
		array(
			'label' 			=> esc_html__( 'Related Posts Count', 'moscow' ),
			'description' 		=> esc_html__( 'Number of posts to show as related posts.', 'moscow' ),
			'section' 			=> 'post',
			'type' 				=> 'select',
			'choices' 			=> array(
				'1' 	=> '1',
				'2' 	=> '2',
				'3' 	=> '3',
				'4' 	=> '4',
				'5' 	=> '5',
				'6' 	=> '6',
				'7' 	=> '7',
				'8' 	=> '8',
				'9' 	=> '9',
				'10' 	=> '10'
			)
		)
	);


	// Related Posts Title
	$wp_customize->add_control( 'blog_related_title',
		array(
			'label' 	=> esc_html__( 'Related Posts Title', 'moscow' ),
			'section' 	=> 'post',
			'type' 		=> 'text'
		)
	);


	// Blog Header
	$wp_customize->add_control( 'blog_header',
		array(
			'label' 			=> esc_html__( 'Enable Blog Header?', 'moscow' ),
			'description' 		=> esc_html__( 'Check this option to show a nice title and description above the posts on the index page.', 'moscow' ),
			'section' 			=> 'post',
			'type' 				=> 'checkbox'
		)
	);


	// Header Title
	$wp_customize->add_control( 'blog_header_title',
		array(
			'label' 	=> esc_html__( 'Blog Header Title', 'moscow' ),
			'section' 	=> 'post',
			'type' 		=> 'text'
		)
	);


	// Header Description
	$wp_customize->add_control( 'blog_header_description',
		array(
			'label' 	=> esc_html__( 'Blog Header Description', 'moscow' ),
			'section' 	=> 'post',
			'type' 		=> 'text'
		)
	);


	// Blog Tags
	$wp_customize->add_control( 'blog_tags',
		array(
			'label' 			=> esc_html__( 'Show Post Tags?', 'moscow' ),
			'section' 			=> 'post',
			'type' 				=> 'checkbox'
		)
	);


	// Blog Author
	$wp_customize->add_control( 'blog_author',
		array(
			'label' 			=> esc_html__( 'Show Post Author?', 'moscow' ),
			'section' 			=> 'post',
			'type' 				=> 'checkbox'
		)
	);


	// Blog Post Navigation
	$wp_customize->add_control( 'blog_post_navigation',
		array(
			'label' 			=> esc_html__( 'Show Post Navigation?', 'moscow' ),
			'section' 			=> 'post',
			'type' 				=> 'checkbox'
		)
	);


	// Social Icons
	$wp_customize->add_control( 'footer_social_icons',
		array(
			'label' 			=> esc_html__( 'Show Social Icons in the Footer?', 'moscow' ),
			'section' 			=> 'footer',
			'type' 				=> 'checkbox'
		)
	);


	// Move Top
	$wp_customize->add_control( 'move_top',
		array(
			'label' 			=> esc_html__( 'Show Move to Top in the Footer?', 'moscow' ),
			'section' 			=> 'footer',
			'type' 				=> 'checkbox'
		)
	);


	// Contact Sidebar
	$wp_customize->add_control( 'contact_sidebar',
		array(
			'label' 			=> esc_html__( 'Enable Sidebar on the Contact Page?', 'moscow' ),
			'section' 			=> 'contact',
			'type' 				=> 'checkbox'
		)
	);


	// Facebook
	$wp_customize->add_control( 'social_facebook',
		array(
			'label' 	=> esc_html__( 'Facebook Profile', 'moscow' ),
			'section' 	=> 'social',
			'type' 		=> 'text'
		)
	);


	// Twitter
	$wp_customize->add_control( 'social_twitter',
		array(
			'label' 	=> esc_html__( 'Twitter Profile', 'moscow' ),
			'section' 	=> 'social',
			'type' 		=> 'text'
		)
	);


	// Google+
	$wp_customize->add_control( 'social_google_plus',
		array(
			'label' 	=> esc_html__( 'Google+ Profile', 'moscow' ),
			'section' 	=> 'social',
			'type' 		=> 'text'
		)
	);


	// LinkedIn
	$wp_customize->add_control( 'social_linkedin',
		array(
			'label' 	=> esc_html__( 'LinkedIn Profile', 'moscow' ),
			'section' 	=> 'social',
			'type' 		=> 'text'
		)
	);


	// Instagram
	$wp_customize->add_control( 'social_instagram',
		array(
			'label' 	=> esc_html__( 'Instagram Profile', 'moscow' ),
			'section' 	=> 'social',
			'type' 		=> 'text'
		)
	);


	// Pinterest
	$wp_customize->add_control( 'social_pinterest',
		array(
			'label' 	=> esc_html__( 'Pinterest Profile', 'moscow' ),
			'section' 	=> 'social',
			'type' 		=> 'text'
		)
	);


	// Youtube
	$wp_customize->add_control( 'social_youtube',
		array(
			'label' 	=> esc_html__( 'YouTube Profile', 'moscow' ),
			'section' 	=> 'social',
			'type' 		=> 'text'
		)
	);

}
add_action( 'customize_register', 'moscow_customize_register' );


/**
 * Data Sanitization
 * -------------------------------------------------
 * Custom functions to sanitize the user input 
 * before saving them to the database.
 * -------------------------------------------------
 * Sanitize Color
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_sanitize_hex_color' ) ) :
function moscow_sanitize_hex_color( $color ) {

	if ( '' === $color ) {
		return '';
	}

	// 3 or 6 hex digits, or the empty string
	if ( preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) ) {
		return $color;
	} else {
		return false;
	}

}
endif;


// Sanitize Checkbox
// -------------------------------------------------

if ( ! function_exists( 'moscow_sanitize_checkbox' ) ) :
function moscow_sanitize_checkbox( $input ) {

	if ( 1 == $input ) {
		return 1;
	} else {
		return false;
	}

}
endif;


// Sanitize Layout
// -------------------------------------------------

if ( ! function_exists( 'moscow_sanitize_layout' ) ) :
function moscow_sanitize_layout( $input ) {

	if ( ! in_array( $input, array( 'normal', 'boxed' ) ) ) {
		$input = 'normal';
	}

	return $input;

}
endif;


// Sanitize Sidebar
// -------------------------------------------------

if ( ! function_exists( 'moscow_sanitize_sidebar' ) ) :
function moscow_sanitize_sidebar( $input ) {

	if ( ! in_array( $input, array( 'left', 'right', 'none' ) ) ) {
		$input = 'right';
	}

	return $input;

}
endif;


// Sanitize Blog
// -------------------------------------------------

if ( ! function_exists( 'moscow_sanitize_blog' ) ) :
function moscow_sanitize_blog( $input ) {

	if ( ! in_array( $input, array( 'classic', 'circle', 'square', '3-col', '2-col' ) ) ) {
		$input = 'classic';
	}

	return $input;

}
endif;


// Sanitize Pagination
// -------------------------------------------------

if ( ! function_exists( 'moscow_sanitize_pagination' ) ) :
function moscow_sanitize_pagination( $input ) {

	if ( ! in_array( $input, array( 'pagination', 'navigation' ) ) ) {
		$input = 'navigation';
	}

	return $input;

}
endif;


// Sanitize Order
// -------------------------------------------------

if ( ! function_exists( 'moscow_sanitize_order' ) ) :
function moscow_sanitize_order( $input ) {

	if ( ! in_array( $input, array( 'DESC', 'ASC', 'rand' ) ) ) {
		$input = 'DESC';
	}

	return $input;

}
endif;


// Sanitize Featured
// -------------------------------------------------

if ( ! function_exists( 'moscow_sanitize_featured' ) ) :
function moscow_sanitize_featured( $input ) {

	if ( ! in_array( $input, array( 'one', 'two', 'three', 'four', 'five' ) ) ) {
		$input = 'five';
	}

	return $input;

}
endif;


// Sanitize Post
// -------------------------------------------------

if ( ! function_exists( 'moscow_sanitize_post' ) ) :
function moscow_sanitize_post( $input ) {

	if ( ! in_array( $input, array( 'classic', 'fitted' ) ) ) {
		$input = 'classic';
	}

	return $input;

}
endif;


// Sanitize Number
// -------------------------------------------------

if ( ! function_exists( 'moscow_sanitize_number' ) ) :
function moscow_sanitize_number( $input ) {

	$input = absint( $input );

	if ( ! empty( $input ) ) {
		if ( $input > 0 ) {
			return $input;
		} else {
			return false;
		}
	} else {
		return false;
	}

}
endif;