<?php

/**
 * Classes to be added to the <body> element of a page.
 * Adds custom classes to the array of body classes.
 * @param array $classes Classes for the body element.
 * @return array
 *
 * @author akshitsethi
 * -------------------------------------------------
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'moscow_body_classes' ) ) :
function moscow_body_classes( $classes ) {

	// Layout
	// -------------------------------------------------

	$classes[] = 'layout-' . esc_html( get_theme_mod( 'layout_style', 'normal' ) );


	// Author
	// -------------------------------------------------

	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}


	// Sidebar
	// -------------------------------------------------

	$sidebar = esc_html( get_theme_mod( 'sidebar' ) );

	if ( 'none' == $sidebar ) {
		$classes[] = 'no-sidebar';
	}


	// Blog
	// -------------------------------------------------

	if ( is_front_page() || is_home() || is_archive() || is_search() ) {
		$classes[] = 'blog-' . esc_html( get_theme_mod( 'blog_style', 'classic' ) );
	}

	$classes[] = 'post-' . esc_html( get_theme_mod( 'post_style', 'classic' ) );

	return $classes;

}
add_filter( 'body_class', 'moscow_body_classes' );
endif;