<?php

/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @author akshitsethi
 *

moscow_post_category()
moscow_post_tags()
moscow_post_time()
moscow_post_author()
moscow_post_comments()
moscow_post_meta()
moscow_breadcrumbs()
moscow_categorized_blog()
moscow_category_transient_flusher()
moscow_pagination()
moscow_wp_comments()
moscow_image_attachment()
moscow_archive_title()

 *
 * -------------------------------------------------
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Post Categories
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_post_category' ) ) :
function moscow_post_category( $echo = true ) {

	$categories_list = get_the_category_list( esc_html__( ', ', 'moscow' ) );

	// Add Paragraphs
	if ( '' != $categories_list ) {
		$meta_text = '<p>' . esc_html( '%1$s', 'moscow' ) . '</p>';
	} else {
		$meta_text = '';
	}

	$output = '<div class="post-categories">';
	$output .= sprintf( $meta_text, $categories_list );
	$output .= '</div><!-- .post-categories -->';

	// Echo or Return
	// -------------------------------------------------

	if ( $echo ) {
		echo $output;
	} else {
		return $output;
	}

}
endif;


/**
 * Post Tags
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_post_tags' ) ) :
function moscow_post_tags( $echo = true ) {

	$tag_list = get_the_tag_list( '', ' ' );

	if ( '' != $tag_list ) {
		$meta_text = '<p>' . esc_html( '%1$s', 'moscow' ) . '</p>';
	} else {
		$meta_text = '';
	}

	$output = '<div class="post-tags">';
	$output .= sprintf( $meta_text, $tag_list, esc_url( get_permalink() ) );
	$output .= '</div><!-- .post-tags -->';

	// Echo or Return
	// -------------------------------------------------

	if ( $echo ) {
		echo $output;
	} else {
		return $output;
	}

}
endif;


/**
 * Post Time
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_post_time' ) ) :
function moscow_post_time( $echo = true ) {

	$time_string 	= '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	$time_string 	= sprintf( $time_string, esc_attr( get_the_date( 'c' ) ), esc_html( get_the_date() ) );
	$posted_on 		= sprintf( '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>' );

	$output = '<div class="post-time">';
	$output .= '<p>' . $posted_on . '</p>';
	$output .= '</div><!-- .post-time -->';

	// Echo or Return
	// -------------------------------------------------

	if ( $echo ) {
		echo $output;
	} else {
		return $output;
	}	

}
endif;


/**
 * Post Author
 * -------------------------------------------------
 */

if( ! function_exists( 'moscow_post_author' ) ) :
function moscow_post_author( $echo = true ) {

	global $post;

	$output = '<div class="post-author">';
	$output .= '<p><span>' . esc_html__( 'by', 'moscow' ) . '</span> <a href="' . esc_url( get_author_posts_url( $post->post_author ) ) . '">' . esc_html( get_the_author() ) . '</a></p>';
	$output .= '</div><!-- .post-author -->';

	// Echo or Return
	// -------------------------------------------------

	if ( $echo ) {
		echo $output;
	} else {
		return $output;
	}

}
endif;


/**
 * Post Comments
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_post_comments' ) ) :
function moscow_post_comments( $echo = true ) {

	if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		$comments = get_comments_number();

		if ( $comments == 0 ) {
			$text = esc_html__( 'No Comments', 'moscow' );
		} elseif ( $comments > 1 ) {
			$text = $comments . esc_html__(' Comments', 'moscow' );
		} else {
			$text = esc_html__( '1 Comment', 'moscow' );
		}

		$output = '<div class="post-comments">';
		$output .= '<p><a href="' . get_comments_link() . '">' . $text . '</a></p>';
		$output .= '</div><!-- .post-comments -->';

		// Echo or Return
		// -------------------------------------------------

		if ( $echo ) {
			echo $output;
		} else {
			return $output;
		}
	}

}
endif;


/**
 * Post Meta
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_post_meta' ) ) :
function moscow_post_meta() {

	moscow_post_category();
	moscow_post_comments();

}
endif;


/**
 * Breadcrumbs
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_breadcrumbs' ) ) :
function moscow_breadcrumbs() {

	if ( get_theme_mod( 'breadcrumbs' ) ) {
		if ( function_exists( 'bcn_display' ) ) {
			echo '<div class="breadcrumbs" typeof="BreadcrumbList" vocab="https://schema.org/">';
			bcn_display();
			echo '</div><!-- .breadcrumbs -->';
		}
	}

}
endif;


/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_categorized_blog' ) ) :
function moscow_categorized_blog() {

	if ( false === ( $all_the_cool_cats = get_transient( 'moscow_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'moscow_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so moscow_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so moscow_categorized_blog should return FALSE.
		return false;
	}

}
endif;


/**
 * Flush out the transients used in moscow_categorized_blog.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_category_transient_flusher' ) ) :
function moscow_category_transient_flusher() {

	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	// Like, beat it. Dig?
	delete_transient( 'moscow_categories' );

}
add_action( 'edit_category', 'moscow_category_transient_flusher' );
add_action( 'save_post',     'moscow_category_transient_flusher' );
endif;


/**
 * Customized pagination for the theme.
 * Works for displaying next & prev page links.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_pagination' ) ) :
function moscow_pagination() {

	$pagination = esc_html( get_theme_mod( 'pagination_style', 'navigation' ) );

	// Navigation
	// -------------------------------------------------

	if ( 'navigation' == $pagination ) {
		if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
			return;
		}

	?>

		<nav class="post-navigation">
			<div class="nav-links">
				<?php

					// Previous
					// -------------------------------------------------

					if ( get_next_posts_link() ) :
						echo '<div class="nav-previous">';
						next_posts_link( '<i class="fa fa-3x fa-angle-left"></i>' );
						echo '&nbsp; ';
						echo '</div><!-- . nav-previous -->';
					endif;


					// Next
					// -------------------------------------------------

					if ( get_previous_posts_link() ) :
						echo '<div class="nav-next">';
						echo ' &nbsp;';
						previous_posts_link( '<i class="fa fa-3x fa-angle-right"></i>' );
						echo '</div><!-- . nav-next -->';
					endif;

				?>
			</div><!-- .nav-links -->
		</nav><!-- .post-navigation -->

	<?php

	} else {
		// Numeric Pagination
		// -------------------------------------------------

		$args = array(
			'mid_size' 	=> 1
		);

		echo '<div class="post-pagination">';
		the_posts_pagination( $args );
		echo '</div><!-- .post-pagination -->';
	}

}
endif;


/**
 * Template for comments and pingbacks.
 * Used as a callback by wp_list_comments() for displaying the comments.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_wp_comments' ) ) :
function moscow_wp_comments( $comment, $args, $depth ) {

	// Reply Text
	$args['reply_text'] = '<i class="fa fa-mail-reply-all"></i>';

	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :

	?>

		<li class="post pingback">
			<p><?php esc_html_e( 'Pingback:', 'moscow' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__( '(Edit)', 'moscow' ), ' ' ); ?></p>

	<?php

		break;
		default :

	?>

	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>" class="comment">
			<footer class="comment-footer">
				<div class="comment-author">
					<span class="comment-author-avatar"><?php echo get_avatar( $comment, 75 ); ?></span>
					<?php printf( esc_html( '%s', 'moscow' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
				</div><!-- .comment-author -->

				<div class="comment-meta">
					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
						<time datetime="<?php comment_time( 'c' ); ?>">
							<?php

								printf( esc_html__( '%1$s at %2$s', 'moscow' ), get_comment_date( 'F jS, Y' ), get_comment_time( 'h:i a' ) );

							?>
						</time>
					</a>
				</div><!-- .comment-meta -->

				<?php if ( '0' == $comment->comment_approved ) : ?>
					<p class="pending-approval">
						<span><?php esc_html_e( 'Your comment is awaiting moderation.', 'moscow' ); ?></span>
					</p><!-- .pending-approval -->
				<?php endif; ?>
			</footer><!-- .comment-footer -->

			<div class="comment-content">
				<?php comment_text(); ?>
			</div><!-- .comment-content -->

			<div class="comment-links">
				<div class="comment-reply">
					<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</div><!-- .comment-reply -->

				<?php edit_comment_link( '<i class="fa fa-edit"></i>', ' ' ); ?>
			</div><!-- .comment-links -->
		</div><!-- .comment -->

	<?php

			break;
	endswitch;

}
endif;


/**
 * Handling image attachments.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_image_attachment' ) ) :
function moscow_image_attachment() {

	$post                = get_post();

	/**
	 * Filter the theme's default attachment size.
	 *
	 * @param array $dimensions {
	 *     An array of height and width dimensions.
	 *
	 *     @type int $height Height of the image in pixels. Default 1170.
	 *     @type int $width  Width of the image in pixels. Default 1170.
	 * }
	 * -------------------------------------------------
	 */

	$attachment_size     = apply_filters( 'moscow_attachment_size', array( 1170, 1170 ) );
	$next_attachment_url = wp_get_attachment_url();

	/**
	 * Grab the IDs of all the image attachments in a gallery so we can get the URL
	 * of the next adjacent image in a gallery, or the first image (if we're
	 * looking at the last image in a gallery), or, in a gallery of one, just the
	 * link to that image file.
	 * -------------------------------------------------
	 */

	$attachment_ids = get_posts( array(
		'post_parent'    	=> 	$post->post_parent,
		'fields'         	=> 	'ids',
		'numberposts'    	=> 	-1,
		'post_status'    	=> 	'inherit',
		'post_type'      	=> 	'attachment',
		'post_mime_type' 	=> 	'image',
		'order'          	=> 	'ASC',
		'orderby'        	=> 	'menu_order ID',
	) );

	/* If there is more than 1 attachment in a gallery. */
	if ( count( $attachment_ids ) > 1 ) {
		foreach ( $attachment_ids as $attachment_id ) {
			if ( $attachment_id == $post->ID ) {
				$next_id = current( $attachment_ids );
				break;
			}
		}

		/* Get the URL of the next image attachment. */
		if ( $next_id ) {
			$next_attachment_url = get_attachment_link( $next_id );
		} else {
			/* or get the URL of the first image attachment. */
			$next_attachment_url = get_attachment_link( array_moscow( $attachment_ids ) );
		}
	}

	printf( '<a href="%1$s" rel="attachment">%2$s</a>',
		esc_url( $next_attachment_url ),
		wp_get_attachment_image( $post->ID, $attachment_size )
	);

}
endif;


/**
 * Display the archive title based on the queried object.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_archive_title' ) ) :
function moscow_archive_title() {

	if ( is_category() ) {
		$title = sprintf( '<span>' . esc_html__( 'Category', 'moscow' ) . '</span><span>' . esc_html( '%s', 'moscow' ) . '</span>', single_cat_title( '', FALSE ) );
	} elseif ( is_tag() ) {
		$title = sprintf( '<span>' . esc_html__( 'Tag', 'moscow' ) . '</span><span>' . esc_html( '%s', 'moscow' ) . '</span>', single_tag_title( '', FALSE ) );
	} elseif ( is_author() ) {
		$title = sprintf( '<span>' . esc_html__( 'Author', 'moscow' ) . '</span><span>' . esc_html( '%s', 'moscow' ) . '</span>', get_the_author() );
	} elseif ( is_year() ) {
		$title = sprintf( '<span>' . esc_html__( 'Year', 'moscow' ) . '</span><span>' . esc_html( '%s', 'moscow' ) . '</span>', get_the_date( esc_html_x( 'Y', 'yearly archives date format', 'moscow' ) ) );
	} elseif ( is_month() ) {
		$title = sprintf( '<span>' . esc_html__( 'Month', 'moscow' ) . '</span><span>' . esc_html( '%s', 'moscow' ) . '</span>', get_the_date( esc_html_x( 'F Y', 'monthly archives date format', 'moscow' ) ) );
	} elseif ( is_day() ) {
		$title = sprintf( '<span>' . esc_html__( 'Day', 'moscow' ) . '</span><span>' . esc_html( '%s', 'moscow' ) . '</span>', get_the_date( esc_html_x( 'F j, Y', 'daily archives date format', 'moscow' ) ) );
	} elseif ( is_tax( 'post_format' ) ) {
		if ( is_tax( 'post_format', 'post-format-gallery' ) ) {
			$title = '<span>' . esc_html__( 'Format', 'moscow' ) . '</span><span>' . esc_html__( 'Galleries', 'moscow' ) . '</span>';
		} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
			$title = '<span>' . esc_html__( 'Format', 'moscow' ) . '</span><span>' . esc_html__( 'Videos', 'moscow' ) . '</span>';
		} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
			$title = '<span>' . esc_html__( 'Format', 'moscow' ) . '</span><span>' . esc_html__( 'Audio', 'moscow' ) . '</span>';
		}
	} elseif ( is_post_type_archive() ) {
		$title = sprintf( '<span>' . esc_html__( 'Archives', 'moscow' ) . '</span><span>' . esc_html( '%s', 'moscow' ) . '</span>', post_type_archive_title( '', FALSE ) );
	} elseif ( is_tax() ) {
		$tax = get_taxonomy( get_queried_object()->taxonomy );
		/* translators: 1: Taxonomy singular name, 2: Current taxonomy term */
		$title = sprintf( '<span>' . esc_html( '%1$s', 'moscow' ) . '</span><span>' . esc_html( '%2$s', 'moscow' ) . '</span>', $tax->labels->singular_name, single_term_title( '', FALSE ) );
	} else {
		$title = '<span>' . esc_html__( 'Archives', 'moscow' ) . '</span>';
	}

	return $title;

}
add_filter( 'get_the_archive_title', 'moscow_archive_title' );
endif;